Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(449)

Unified Diff: sdk/lib/io/http.dart

Issue 11770004: Rename Date to DateTime. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments and keep Backwards-compatibility class Date. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/io/file_impl.dart ('k') | sdk/lib/io/http_headers.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/io/http.dart
diff --git a/sdk/lib/io/http.dart b/sdk/lib/io/http.dart
index 5b1809fed02b2da52012e86233f6955622702b3f..2862036c416ff7485e2fe175183d0b93b50f5688 100644
--- a/sdk/lib/io/http.dart
+++ b/sdk/lib/io/http.dart
@@ -298,7 +298,7 @@ abstract class HttpHeaders {
* Adds a header value. The header named [name] will have the value
* [value] added to its list of values. Some headers are single
* values and for these adding a value will replace the previous
* value. If the value is of type Date a HTTP date format will be
* applied. If the value is a [:List:] each element of the list will
* be added separately. For all other types the default [:toString:]
* method will be used.
@@ -343,21 +343,21 @@ abstract class HttpHeaders {
/**
* Gets and sets the date. The value of this property will
* reflect the "Date" header.
*/
- Date date;
+ DateTime date;
/**
* Gets and sets the expiry date. The value of this property will
* reflect the "Expires" header.
*/
- Date expires;
+ DateTime expires;
/**
* Gets and sets the 'if-modified-since' date. The value of this property will
* reflect the "if-modified-since" header.
*/
- Date ifModifiedSince;
+ DateTime ifModifiedSince;
/**
* Gets and sets the host part of the "Host" header for the
@@ -552,7 +552,7 @@ abstract class Cookie {
/**
* Gets and sets the expiry date.
*/
- Date expires;
+ DateTime expires;
/**
* Gets and sets the max age. A value of [:0:] means delete cookie
« no previous file with comments | « sdk/lib/io/file_impl.dart ('k') | sdk/lib/io/http_headers.dart » ('j') | no next file with comments »
@@ -298,7 +298,7 @@ abstract class HttpHeaders {
* [value] added to its list of values. Some headers are single
* values and for these adding a value will replace the previous
- * value. If the value is of type Date a HTTP date format will be
+ * value. If the value is of type DateTime a HTTP date format will be
* applied. If the value is a [:List:] each element of the list will
* be added separately. For all other types the default [:toString:]
@@ -343,21 +343,21 @@ abstract class HttpHeaders {
/**
* Gets and sets the date. The value of this property will
- * reflect the "Date" header.
+ * reflect the "DateTime" header.
*/

Powered by Google App Engine
This is Rietveld 408576698